==> moodle-1.4.3-pgsql.tgz: moodle/lang/zh_cn/editor.php <==
<?PHP // $Id$ 
      // editor.php - created with Moodle 1.2.1 (2004032500)


$string['about'] = 'ڴ˱༭';
$string['absbottom'] = 'ײ';
$string['middle'] = '';
$string['address'] = 'ַ';
$string['alignment'] = 'λ';
$string['alternatetext'] = 'ʾı';
$string['baseline'] = '׼';
$string['bold'] = '';
$string['borderthickness'] = '߿';
$string['bottom'] = 'ײ';
$string['browse'] = '';
$string['cancel'] = 'ȡ';
$string['cellpadding'] = '߿';
$string['cellspacing'] = '߾';
$string['choosechar'] = 'ѡַ';
$string['chooseicon'] = 'ѡҪı';
$string['close'] = 'ر';
$string['cols'] = '';
$string['copy'] = 'ѡ';
$string['createfolder'] = 'ļ';
$string['createlink'] = '';
$string['cut'] = 'ѡ';
$string['delete'] = 'ɾ';
$string['filebrowser'] = 'ļ';
$string['forecolor'] = 'ɫ';
$string['heading'] = '';
$string['height'] = '߶';
$string['hilitecolor'] = 'ɫ';
$string['horizontal'] = 'ˮƽλ';
$string['horizontalrule'] = 'ˮƽ';
$string['htmlmode'] = 'лHTMLģʽ';
$string['imageurl'] = 'ͼƬַ';
$string['indent'] = '';
$string['insertchar'] = 'ַ';
$string['insertimage'] = 'ͼƬ';
$string['insertlink'] = '';
$string['insertsmile'] = '';
$string['inserttable'] = '';
$string['italic'] = 'б';
$string['justifycenter'] = '';
$string['justifyfull'] = '˶';
$string['justifyleft'] = '';
$string['justifyright'] = '';
$string['layout'] = 'ʽ';
$string['left'] = '';
$string['linkproperties'] = 'Link properties';
$string['linktarget'] = 'Ŀ';
$string['linktargetblank'] = '´';
$string['linktargetnone'] = '';
$string['linktargetother'] = 'Other (out of order)';
$string['linktargetself'] = 'ͬһ';
$string['linktargettop'] = 'ͬһ';
$string['linktitle'] = '';
$string['linkurl'] = 'URL';
$string['middle'] = '';
$string['move'] = 'ƶ';
$string['normal'] = '';
$string['notimage'] = 'ѡļͼƬ. ѡһͼƬ!';
$string['notset'] = 'δ';
$string['ok'] = 'ȷ';
$string['orderedlist'] = 'б';
$string['outdent'] = '';
$string['paste'] = 'ճ';
$string['path'] = '·';
$string['percent'] = 'ٷֱ';
$string['pixels'] = '';
$string['popupeditor'] = 'ڵĴ󴰿д򿪱༭';
$string['preformatted'] = 'Ĭ϶';
$string['preview'] = 'Ԥ';
$string['properties'] = 'Properties';
$string['redo'] = '';
$string['removelink'] = 'ɾ';
$string['rename'] = '';
$string['right'] = '';
$string['rows'] = '';
$string['selection'] = 'ѡ';
$string['showhelp'] = '༭ʹð';
$string['size'] = 'С';
$string['spacing'] = 'λ';
$string['strikethrough'] = 'ɾ';
$string['subscript'] = '±';
$string['superscript'] = 'ϱ';
$string['textindicator'] = 'ǰ';
$string['textmode'] = 'ıģʽ.  [<>] ťģʽ.';
$string['texttop'] = 'ֶ';
$string['top'] = '';
$string['type'] = '';
$string['underline'] = '»';
$string['undo'] = 'ϲ';
$string['unorderedlist'] = 'Ŀ';
$string['upload'] = 'ϴ';
$string['vertical'] = 'ֱλ';
$string['width'] = '';
$string['zip'] = 'Zip';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/zh_cn/editor.php <==
<?PHP // $Id$



$string['about'] = 'ڴ˱༭';
$string['absbottom'] = 'ײ';
$string['address'] = 'ַ';
$string['alertnoselectedtext'] = 'ѡ!';
$string['alignment'] = 'λ';
$string['alternatetext'] = 'ʾı';
$string['anchorhelp'] = 'ֻһӵ㡣Ҫֹһӡ';
$string['anchorname'] = 'ӵ';
$string['anchors'] = 'ӵ';
$string['baseline'] = '׼';
$string['bold'] = '';
$string['borderthickness'] = '߿';
$string['bottom'] = 'ײ';
$string['browse'] = '';
$string['cancel'] = 'ȡ';
$string['cellpadding'] = '߿';
$string['cellspacing'] = '߾';
$string['choosechar'] = 'ѡַ';
$string['chooseicon'] = 'ѡҪı';
$string['close'] = 'ر';
$string['closeafterreplace'] = '滻ر';
$string['cols'] = '';
$string['copy'] = 'ѡ';
$string['createanchor'] = 'ӵ';
$string['createfolder'] = 'ļ';
$string['createlink'] = '';
$string['cut'] = 'ѡ';
$string['cutpastemozilla'] = 'ܱǸڲʹϰߵĿݼ(ճť)ճı߱༭һЩ汾MozillaFirefoxðȫġ<br /><br />֪Ľ<br /> (1) SHIFT+InsertCTRL+v <br /> (2) ʹ˵Edit->Paste<br /> (3) ͨ༭user.jsıĲ<br /><br />ġȷøߵ㡰ص༭';
$string['delete'] = 'ɾ';
$string['filebrowser'] = 'ļ';
$string['findwhat'] = '';
$string['fontname'] = '';
$string['fontsize'] = 'ֺ';
$string['forecolor'] = 'ɫ';
$string['formatblock'] = 'ʽ';
$string['fullscreen'] = 'ȫĻ༭';
$string['heading'] = '';
$string['height'] = '߶';
$string['hilitecolor'] = 'ɫ';
$string['horizontal'] = 'ˮƽλ';
$string['horizontalrule'] = 'ˮƽ';
$string['htmlmode'] = 'лHTMLģʽ';
$string['imageurl'] = 'ͼƬַ';
$string['indent'] = '';
$string['insertchar'] = 'ַ';
$string['insertimage'] = 'ͼƬ';
$string['insertlink'] = '';
$string['insertsmile'] = '';
$string['inserttable'] = '';
$string['italic'] = 'б';
$string['itemsreplaced'] = 'Ŀ滻';
$string['justifycenter'] = '';
$string['justifyfull'] = '˶';
$string['justifyleft'] = '';
$string['justifyright'] = '';
$string['layout'] = 'ʽ';
$string['left'] = '';
$string['lefttoright'] = '';
$string['linkproperties'] = '';
$string['linktarget'] = 'Ŀ';
$string['linktargetblank'] = '´';
$string['linktargetnone'] = '';
$string['linktargetother'] = '';
$string['linktargetself'] = 'ͬһ';
$string['linktargettop'] = 'ͬһ';
$string['linktitle'] = '';
$string['linkurl'] = 'URL';
$string['matchcase'] = 'ƥСд';
$string['middle'] = '';
$string['minimize'] = 'С༭';
$string['move'] = 'ƶ';
$string['nolink'] = 'Զ';
$string['normal'] = '';
$string['notimage'] = 'ѡļͼƬ. ѡһͼƬ!';
$string['notset'] = 'δ';
$string['ok'] = 'ȷ';
$string['options'] = 'ѡ';
$string['orderedlist'] = 'б';
$string['outdent'] = '';
$string['paste'] = 'ճ';
$string['path'] = '·';
$string['percent'] = 'ٷֱ';
$string['pixels'] = '';
$string['popupeditor'] = 'ڵĴ󴰿д򿪱༭';
$string['preformatted'] = 'Ĭ϶';
$string['preview'] = 'Ԥ';
$string['properties'] = '';
$string['redo'] = '';
$string['regularexpressions'] = 'ʹʽ';
$string['removelink'] = 'ɾ';
$string['rename'] = '';
$string['replaceall'] = '滻ȫ';
$string['replacewith'] = '滻';
$string['right'] = '';
$string['righttoleft'] = '';
$string['rows'] = '';
$string['searchandreplace'] = '滻';
$string['searchnotfound'] = 'δҵַ';
$string['selectcolor'] = 'ѡɫ';
$string['selection'] = 'ѡ';
$string['showhelp'] = '༭ʹð';
$string['size'] = 'С';
$string['spacing'] = 'λ';
$string['strikethrough'] = 'ɾ';
$string['subscript'] = '±';
$string['superscript'] = 'ϱ';
$string['textindicator'] = 'ǰ';
$string['textmode'] = 'ıģʽ[<>]ťģʽ.';
$string['texttop'] = 'ֶ';
$string['top'] = '';
$string['type'] = '';
$string['underline'] = '»';
$string['undo'] = 'ϲ';
$string['unorderedlist'] = 'Ŀ';
$string['upload'] = 'ϴ';
$string['vertical'] = 'ֱλ';
$string['width'] = '';
$string['wordclean'] = 'Word HTML';
$string['zip'] = 'Zip';
?>
